# eric7.Preferences.ConfigurationPages.ProjectBrowserPage

Module implementing the Project Browser configuration page.

### Global Attributes

None

### Classes

ProjectBrowserPage | Class implementing the Project Browser configuration page.

### Functions

create | Module function to create the configuration page.

## ProjectBrowserPage

Class implementing the Project Browser configuration page.

### Derived from

ConfigurationPageBase, Ui_ProjectBrowserPage

### Class Attributes

None

### Class Methods

None

### Methods

ProjectBrowserPage | Constructor
__populateProjectBrowserList | Private method to populate the project browsers list.
__setProjectBrowsersList | Private method to check the project browser entries according to the selected project type.
__storeProjectBrowsersList | Private method to store the list of enabled browsers for the selected project type.
on_followCursorLineCheckBox_toggled | Private slot to handle the change of the 'Follow Cursor Line' checkbox.
on_followEditorCheckBox_toggled | Private slot to handle the change of the 'Follow Editor' checkbox.
on_projectTypeCombo_activated | Private slot to set the browser checkboxes according to the selected project type.
save | Public slot to save the Project Browser configuration.

### Static Methods

None

#### ProjectBrowserPage (Constructor)

ProjectBrowserPage()

Constructor

#### ProjectBrowserPage.__populateProjectBrowserList

__populateProjectBrowserList()

Private method to populate the project browsers list.

#### ProjectBrowserPage.__setProjectBrowsersList

__setProjectBrowsersList(projectType)

Private method to check the project browser entries according to the selected project type.

projectType (str)
  selected project type

#### ProjectBrowserPage.__storeProjectBrowsersList

__storeProjectBrowsersList(projectType)

Private method to store the list of enabled browsers for the selected project type.

projectType (str)
  type of the selected project

#### ProjectBrowserPage.on_followCursorLineCheckBox_toggled

on_followCursorLineCheckBox_toggled(checked)

Private slot to handle the change of the 'Follow Cursor Line' checkbox.

checked (bool)
  flag indicating the state of the checkbox

#### ProjectBrowserPage.on_followEditorCheckBox_toggled

on_followEditorCheckBox_toggled(checked)

Private slot to handle the change of the 'Follow Editor' checkbox.

checked (bool)
  flag indicating the state of the checkbox

#### ProjectBrowserPage.on_projectTypeCombo_activated

on_projectTypeCombo_activated(index)

Private slot to set the browser checkboxes according to the selected project type.

index (int)
  index of the selected project type

#### ProjectBrowserPage.save

save()

Public slot to save the Project Browser configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up